seesus API documentation
Description: seesus A Python tool for checking whether a textual expression aligns with sustainability as defined by the United Nations Sustainable Development …

# Package `seesus`

## Seesus

A Python tool for checking whether a textual expression aligns with sustainability as defined by the United Nations Sustainable Development Goals.

version = "1.0.0" title = "seesus" url = "https://github.com/caimeng2/seesus" license = "LGPL-3.0"

Expand source code

    """
    seesus
    ------
    A Python tool for checking whether a textual expression aligns with sustainability as defined by the United Nations Sustainable Development Goals.

    __version__ = "1.0.0"
    __title__ = "seesus"
    __url__ = "https://github.com/caimeng2/seesus"
    __license__ = "LGPL-3.0"
    """

    from seesus.seesus import SeeSus

## Sub-modules

`seesus.SDG_desc`

  The United Nations description of SDGs and targets. Source: https://sdgs.un.org/goals, https://unstats.un.org/sdgs/indicators/indicators-list/

`seesus.SDG_keys`

  Sustainability search terms as defined by the United Nations Sustainable Development Goals.

`seesus.see_keys`

  Classification of SDG targets into social, environmental, and economic sustainability.

`seesus.seesus`

  Identify 17 Sustainable Development Goals (SDGs) and their 169 targets in text, and classify into social, environmental, and economic sustainability.

`seesus.tests`